"""
PyLocator
=========

A program for localisation of EEG-electrodes from CT/MRI-volumes. 

Dependencies:
python
scipy, numpy
Numeric (needed for VTK)
vtk
pygtk, gtkglext
"""

__version__ = "0.29"

#from pylocator import main
